@@ -3,25 +3,22 @@
 #include <unistd.h>
 #include <math.h>
 
-#include "lv2plugin.hpp"
-#include "synthdata.hpp"
+#include <lvtk-1/lvtk/plugin.hpp>
+
 #include "amp.hpp"
 
-using namespace LV2;
+using namespace lvtk;
 
 Amp::Amp(double rate)
 :Plugin<Amp>(p_n_ports)
  {
-	gain=1;
  }
 
 void Amp::run(uint32_t nframes)
 {
-	gain = *p(p_gain);
-	unsigned int l2;
-	for (l2 = 0; l2 < nframes; l2++)
+	for (unsigned int l2 = 0; l2 < nframes; l2++)
 	{
-		p(p_output)[l2] = gain * p(p_input)[l2];
+		p(p_output)[l2] = *p(p_gain) * p(p_input)[l2];
 	}
 }
 
