@@ -3,8 +3,7 @@
 #include <unistd.h>
 #include <math.h>
 
-#include "lv2plugin.hpp"
-#include "synthdata.hpp"
+#include <lvtk-1/lvtk/plugin.hpp>
 
 #include "cvs.hpp"
 
