@@ -3,10 +3,9 @@
 #include <unistd.h>
 #include <math.h>
 
-#include "synthdata.hpp"
 #include "hztovc.hpp"
 
-using namespace LV2;
+using namespace lvtk;
 
 HzToVc::HzToVc(double rate)
 :Plugin<HzToVc>(p_n_ports)
