@@ -3,11 +3,11 @@
 #include <unistd.h>
 #include <math.h>
 
-#include "lv2plugin.hpp"
-#include "synthdata.hpp"
+#include <lvtk-1/lvtk/plugin.hpp>
+
 #include "inv.hpp"
 
-using namespace LV2;
+using namespace lvtk;
 
 Inv::Inv(double rate)
 :Plugin<Inv>(p_n_ports)
