@@ -3,29 +3,13 @@
 #include <unistd.h>
 #include <math.h>
 
-#include "lv2plugin.hpp"
-#include "synthdata.hpp"
+#include <lvtk-1/lvtk/plugin.hpp>
 
 #include "slew.hpp"
 
 Slew::Slew(double rate):
 Plugin<Slew>(p_n_ports)
 {
-	//QString qs;
-	//int l1;
-
-	//setGeometry(MODULE_NEW_X, MODULE_NEW_Y, MODULE_SLEW_WIDTH, MODULE_SLEW_HEIGHT);
-	//port_M_in = new Port(tr("In"), PORT_IN, 0, this);
-	//cv.out_off = 55;
-	//port_out = new Port(tr("Out"), PORT_OUT, 0, this);
-	//timeUp = 0.5;
-	//timeDown = 0.5;
-	//configDialog->addSlider(tr("Time Up"), timeUp, 0, 10);
-	//configDialog->addSlider(tr("Time Down"), timeDown, 0, 10);
-	//for (l1 = 0; l1 < synthdata->poly; l1++) {
-	//	lastData[l1] = 0;
-	//}
-
 	lastData = 0;
 	m_rate = rate;
 }
