@@ -3,10 +3,9 @@
 #include <unistd.h>
 #include <math.h>
 
-#include "synthdata.hpp"
 #include "vctohz.hpp"
 
-using namespace LV2;
+using namespace lvtk;
 
 VcToHz::VcToHz(double rate)
 :Plugin<VcToHz>(p_n_ports)
